November 2015 Decisions

Advanced Decision Search
Home Court Decisions November 2015 Decisions
November 24, 2015
Decision List | PDF |  | Entries for Cases and Motions
No. 209 SSM 26 | PDF | WPD | The People v. Stephen Pellegrino
No. 207 SSM 24 / No. 208 SSM 25 | PDF | WPD | The People v. Mactar Sougou /The People v. Rita Thompson
No. 170 | PDF | WPD | The People v. Abdelouahad Afilal
No. 167 / No. 168 / No. 169 | PDF | WPD | The People v. Joseph Conceicao / The People v. Federico Perez / The People v. Javier Sanchez
| November 23, 2015
Decision List | PDF |  | Entries for Cases and Motions
No. 211 SSM 17 | PDF | WPD | Ainsworth M. Bennett v. St. John's Home
No. 177 | PDF | WPD | The Matter of Crystal Hawkins v. Elizabeth Berlin
No. 175 | PDF | WPD | The People v. Ally Golo
No. 174 | PDF | WPD | The People v. Julio Negron
No. 166 | PDF | WPD | The People v. Everett M. Durant
No. 165 | PDF | WPD | The People v. Nugene Ambers
No. 164 | PDF | WPD | The People v. Davon Harris
No. 162 | PDF | WPD | The People v. Alma Caldavado
No. 157 | PDF | WPD | The People v Frankie Hatton
| November 19, 2015
Decision List | PDF |  | Entries for Cases and Motions
No.210 SSM 22 | PDF | WPD | Switzerland Green v. Metropolitan Transportation Authority Bus Company
No.176 | PDF | WPD | The People v. Samuel Small, Also Known as Samuel Smalls
No.160 | PDF | WPD | The People v. Antonio Martinez
No.158 | PDF | WPD | The Matter of Estevan Gentil v. Hon. Ira Margulis
No.154 | PDF | WPD | The People v. Matthew P.
No.152 | PDF | WPD | The People v. Willie L. Wragg
No.151 | PDF | WPD | The Matter of Sierra Club v. Village of Painted Post
No.139 | PDF | WPD | The Matter of Walter E. Carver v. State of New York
November 18, 2015
Decision List | PDF |  | Entries for Cases and Motions
No.173 | PDF | WPD | In the Matter of Anthony Frank Fizzinoglia
| No.171 | PDF | WPD | The People v. Daniel Israel
No. 159 | PDF | WPD | The People v. Pettis Hardy
No. 155 | PDF | WPD | The People v. Alfred Gary